# -*- coding: utf-8 -*-
from ._tea import TEA, check_pymalloc
from .pytea import TEA as PYTEA

__version__ = "0.2.0"
__author__ = "synodriver"
